<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>Application</name>
    <message>
        <location filename="../reader/Application.cpp" line="39"/>
        <source>Document Viewer</source>
        <translation>Vizualizator de Documente </translation>
    </message>
    <message>
        <location filename="../reader/Application.cpp" line="40"/>
        <source>Document Viewer is a tool for reading document files, supporting PDF, DJVU, DOCX etc.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AttrScrollWidget</name>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="46"/>
        <source>Location</source>
        <translation>Amplasare </translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="47"/>
        <source>Subject</source>
        <translation>Subiect </translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="48"/>
        <source>Author</source>
        <translation>Autor </translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="49"/>
        <source>Keywords</source>
        <translation>Cuvintele cheie </translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="50"/>
        <source>Producer</source>
        <translation>Producător </translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="51"/>
        <source>Creator</source>
        <translation>Compilator </translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="52"/>
        <source>Time created</source>
        <translation>Perioada creării</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="53"/>
        <source>Time modified</source>
        <translation>Perioada modificării</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="54"/>
        <source>Format</source>
        <translation>Format </translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="55"/>
        <source>Pages</source>
        <translation>Paginile </translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="56"/>
        <source>Optimized</source>
        <translation>Optimizat </translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="57"/>
        <source>Security</source>
        <translation>Securitate </translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="59"/>
        <source>Page size</source>
        <translation>Mărimea paginii </translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="60"/>
        <source>File size</source>
        <translation>Mărimea fișierului </translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="65"/>
        <source>Basic info</source>
        <translation>Informații de bază </translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="85"/>
        <source>Unknown</source>
        <translation>Necunoscut </translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>Yes</source>
        <translation>Da </translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>No</source>
        <translation>Nu </translation>
    </message>
</context>
<context>
    <name>BookMarkWidget</name>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="64"/>
        <source>Add bookmark</source>
        <translation>Adăugarea marcaj </translation>
    </message>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="220"/>
        <source>Are you sure you want to delete all bookmarks?</source>
        <translation>Doriți să ștergeți toate marcajele? </translation>
    </message>
</context>
<context>
    <name>BrowserMenu</name>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="39"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="52"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="56"/>
        <source>Copy</source>
        <translation>Copiere </translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="43"/>
        <source>Remove annotation</source>
        <translation>Eliminarea adnotare</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="44"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="73"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="134"/>
        <source>Add annotation</source>
        <translation>Adăugarea adnotare</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="47"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="77"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="85"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="129"/>
        <source>Remove bookmark</source>
        <translation>Eliminarea marcajului</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="49"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="79"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="87"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="131"/>
        <source>Add bookmark</source>
        <translation>Adăugarea marcajului</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="60"/>
        <source>Highlight</source>
        <translation>Evidențiere </translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="69"/>
        <source>Remove highlight</source>
        <translation>Scoatere evidențiere</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="81"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="124"/>
        <source>Search</source>
        <translation>Căutare </translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="92"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="140"/>
        <source>Exit fullscreen</source>
        <translation> Ieșire ecran complet </translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="94"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="142"/>
        <source>Fullscreen</source>
        <translation>Ecran complet </translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="97"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="145"/>
        <source>Slide show</source>
        <translation>Prezentare </translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="100"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="148"/>
        <source>First page</source>
        <translation>Prima pagină </translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="101"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="149"/>
        <source>Previous page</source>
        <translation>Pagina precedentă </translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="107"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="155"/>
        <source>Next page</source>
        <translation>Pagina următoare </translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="108"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="156"/>
        <source>Last page</source>
        <translation>Ultima pagină </translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="116"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="164"/>
        <source>Rotate left</source>
        <translation>Rotire stânga </translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="117"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="165"/>
        <source>Rotate right</source>
        <translation>Rotire dreapta </translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="120"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="168"/>
        <source>Print</source>
        <translation>Printare </translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="121"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="169"/>
        <source>Document info</source>
        <translation>Informație document </translation>
    </message>
</context>
<context>
    <name>Central</name>
    <message>
        <location filename="../reader/uiframe/Central.cpp" line="141"/>
        <source>Documents</source>
        <translation>Documente</translation>
    </message>
</context>
<context>
    <name>CentralDocPage</name>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="166"/>
        <source>The format is not supported</source>
        <translation>Formatul dat nu este acceptat </translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="208"/>
        <source>Open failed</source>
        <translation>Deschidere eșuata</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="210"/>
        <source>Please check if the file is damaged</source>
        <translation>Vă rugăm să vă asigurați dacă fișierul nu este deteriorat </translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="212"/>
        <source>Conversion failed, please check if the file is damaged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="420"/>
        <source>Save failed</source>
        <translation>Salvare eșuată </translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="426"/>
        <source>Saved successfully</source>
        <translation>Salvare cu succes </translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="444"/>
        <source>Save as</source>
        <translation>Salvează ca </translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="453"/>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="463"/>
        <source>Invalid file name</source>
        <translation>Nume de fișier inacceptabil </translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="455"/>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="465"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK </translation>
    </message>
</context>
<context>
    <name>CentralNavPage</name>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="35"/>
        <source>Drag documents here</source>
        <translation>Trageți documentele aici </translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="41"/>
        <source>Format supported: %1</source>
        <translation>Formatul acceptat: %1 </translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="47"/>
        <source>Select File</source>
        <translation>Selectați Fișierul</translation>
    </message>
</context>
<context>
    <name>DocSheet</name>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="326"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="354"/>
        <source>The bookmark has been removed</source>
        <translation>Marcajul a fost eliminat</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="527"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="542"/>
        <source>Please select the text</source>
        <translation>Vă rugăm să selectați textul</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="592"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="601"/>
        <source>The annotation has been removed</source>
        <translation>Adnotare a fost eliminată</translation>
    </message>
</context>
<context>
    <name>EncryptionPage</name>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="50"/>
        <source>Encrypted file, please enter the password</source>
        <translation>Fișierul criptat, introduceți vă rog parola</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="56"/>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="61"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK </translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="105"/>
        <source>Wrong password</source>
        <translation>Parola incorectă</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="125"/>
        <source>Previous</source>
        <translation>Precedent</translation>
    </message>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="133"/>
        <source>Next</source>
        <translation>Următor</translation>
    </message>
</context>
<context>
    <name>HandleMenu</name>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="35"/>
        <source>Select Text</source>
        <translation>Selectați textul</translation>
    </message>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="43"/>
        <source>Hand Tool</source>
        <translation>Instrumentul ”Mâna”</translation>
    </message>
</context>
<context>
    <name>NotesWidget</name>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="67"/>
        <source>Add annotation</source>
        <translation>Adăugarea adnotării</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="189"/>
        <source>Are you sure you want to delete all annotations?</source>
        <translation>Doriți să ștergeți toate adnotările?</translation>
    </message>
</context>
<context>
    <name>PagingWidget</name>
    <message>
        <location filename="../reader/widgets/PagingWidget.cpp" line="212"/>
        <source>Invalid page number</source>
        <translation>Numărul de pagină nevalabil</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../reader/widgets/ProgressDialog.cpp" line="18"/>
        <source>Converting</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../reader/app/DBusObject.cpp" line="103"/>
        <source>Document not saved</source>
        <translation>Documentul nu a fost salvat</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="35"/>
        <source>Save the changes to &quot;%1&quot;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anulare</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Discard</source>
        <comment>button</comment>
        <translation>Renunțare</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="38"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvare</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="50"/>
        <source>Delete</source>
        <translation>Șterge</translation>
    </message>
</context>
<context>
    <name>ScaleMenu</name>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="35"/>
        <source>Two-Page View</source>
        <translation>Afișare două pagini</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="36"/>
        <source>1:1 size</source>
        <translation>1:1 mărime</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="37"/>
        <source>Fit Page</source>
        <translation>Potrivire pagină</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="38"/>
        <source>Fit Height</source>
        <translation>Potrivire înălțime</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="39"/>
        <source>Fit Width</source>
        <translation>Potrivire lățime</translation>
    </message>
</context>
<context>
    <name>SearchResWidget</name>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="60"/>
        <source>No search results</source>
        <translation>Nici-un rezultat</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="109"/>
        <source>%1 items found</source>
        <translation>%1  obiecte găsite</translation>
    </message>
</context>
<context>
    <name>SecurityDialog</name>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="72"/>
        <source>This document is trying to connect to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="73"/>
        <source>If you trust the website, click Allow, otherwise click Block.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="76"/>
        <source>Block</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="77"/>
        <source>Allow</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SheetSidebar</name>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="84"/>
        <source>Thumbnails</source>
        <translation>Miniaturi</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="99"/>
        <source>Catalog</source>
        <translation>Catalog</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="112"/>
        <source>Bookmarks</source>
        <translation>Marcaje</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="127"/>
        <source>Annotations</source>
        <translation>Adnotări</translation>
    </message>
</context>
<context>
    <name>ShortCutShow</name>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="58"/>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="79"/>
        <source>Files</source>
        <translation>Fișiere</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="100"/>
        <source>Display</source>
        <translation>Afișaj</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="120"/>
        <source>Tools</source>
        <translation>Instrumente</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="142"/>
        <source>Edit</source>
        <translation>Editare</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Exit</source>
        <translation>Ieșire</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="200"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="242"/>
        <source>Help</source>
        <translation>Ajutor</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Page up</source>
        <translation>Pagină sus</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Page down</source>
        <translation>Pagină jos</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <source>Open</source>
        <translation>Accesa</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Zoom in</source>
        <translation>A mări</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Zoom out</source>
        <translation>A Micșora</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <source>Zoom in/Zoom out</source>
        <translation>Mărește/Micșorează</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <source>Save as</source>
        <translation>Salvează ca</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <source>Print</source>
        <translation>Printare</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Save</source>
        <translation>Salvare</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Thumbnails</source>
        <translation>Miniaturi</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>1:1 size</source>
        <translation>1:1 mărime</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Fit height</source>
        <translation>Potrivire înălțime</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Fit width</source>
        <translation>Potrivire lățime</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Rotate left</source>
        <translation>Rotire stânga</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Rotate right</source>
        <translation>Rotire dreapta</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Select text</source>
        <translation>Selectați textul</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Hand tool</source>
        <translation>Instrumentul ”Mâna”</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Add bookmark</source>
        <translation>Adăugarea marcaj</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Delete</source>
        <translation>Șterge</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Magnifier</source>
        <translation>Lupă</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Slide show</source>
        <translation>Prezentare</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Fullscreen</source>
        <translation>Ecran complet</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Copy</source>
        <translation>Copiere</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Cut</source>
        <translation>Decupare</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Paste</source>
        <translation>Lipire</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="240"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Undo</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="240"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Select all</source>
        <translation>Selectați tot</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="200"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="240"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="242"/>
        <source>Display shortcuts</source>
        <translation>Afișare comenzi rapide</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Add annotation</source>
        <translation>Adăugarea adnotării</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Highlight</source>
        <translation>Evidențiere</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Search</source>
        <translation>Căutare</translation>
    </message>
</context>
<context>
    <name>SideBarImageListView</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="194"/>
        <source>Copy</source>
        <translation>Copiere </translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="199"/>
        <source>Remove annotation</source>
        <translation>Eliminarea adnotare</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="204"/>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="223"/>
        <source>Remove all</source>
        <translation>Eliminare tot</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="218"/>
        <source>Remove bookmark</source>
        <translation>Eliminarea marcajului</translation>
    </message>
</context>
<context>
    <name>SideBarImageViewModel</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageViewModel.cpp" line="135"/>
        <source>Page %1</source>
        <translation>Pagina %1</translation>
    </message>
</context>
<context>
    <name>TitleMenu</name>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New window</source>
        <translation>Fereastră nouă</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New tab</source>
        <translation>Filă nouă</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="110"/>
        <source>Save</source>
        <translation>Salvare</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <source>Save as</source>
        <translation>Salvează ca</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Display in file manager</source>
        <translation>Afișare manager de fișiere</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Magnifer</source>
        <translation>Lupă</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="50"/>
        <source>Tools</source>
        <translation>Instrumente</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Search</source>
        <translation>Căutare</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TitleWidget</name>
    <message>
        <location filename="../reader/uiframe/TitleWidget.cpp" line="37"/>
        <source>Thumbnails</source>
        <translation>Miniaturi</translation>
    </message>
</context>
<context>
    <name>TransparentTextEdit</name>
    <message>
        <location filename="../reader/widgets/TransparentTextEdit.cpp" line="82"/>
        <source>Input limit reached</source>
        <translation>Limită de intrare atinsă</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../reader/main.cpp" line="40"/>
        <source>Document File Path.</source>
        <translation>Cale Fișierului de Document</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="41"/>
        <location filename="../reader/main.cpp" line="45"/>
        <source>FilePath</source>
        <translation>Cale Fișierului</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="44"/>
        <source>ThumbnailPath Path.</source>
        <translation>Cale ThumbnailPath </translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="49"/>
        <source>Generate thumbnail.</source>
        <translation>Generează miniatură</translation>
    </message>
</context>
</TS>
